/*
 * 
 * Read temperature from the TMP75B on the I2C bus and
 * display it in Fahrenheit on the 8 LED's.
 * 
 * BOARD: ATtiny412/402/212/202
 * Chip: ATtiny202
 * Clock Speed: 10 MHz
 * Programmer: jtag2updi (megaTinyCore)
 * 
 */
#include <TinyMegaI2CMaster.h>

void setup() {
  TinyMegaI2C.init();
  TinyMegaI2C.start(72,0);                              // tmp75b Address: 1001000 (72) (0x48)
                                                        // TinyMegaI2C.start(7BitAddress,R/W)
                                                        // R/W = 0 in first byte indicates that the
                                                        // next byte will be written to the pointer
                                                        // register.
  TinyMegaI2C.write(0x00);                              // Write 0 to Pointer Register, so it points
                                                        // to the Temperature Register
  TinyMegaI2C.stop();
}


void loop() {
  delay(100);
  
  TinyMegaI2C.start(72,2);                              // tmp75b Address: 1001000 (72) (0x48)
                                                        // TinyMegaI2C.start(7BitAddress,R/W)
                                                        // R/W = 2 indicates that 2 bytes will be
                                                        // read from the register to which the 
                                                        // Pointer Register points.
  byte MSB = TinyMegaI2C.read();                        // MSB sent first
  byte LSB = TinyMegaI2C.read();                        // LSB sent last.
  TinyMegaI2C.stop();
  
  int binary_C = (MSB << 4) + (LSB >> 4);               // Note, binary_C is 16x larger than the 
                                                        // actual temperature. The 'int' data
                                                        // type is appropriate as the tmp75b uses
                                                        // 12 bits to represent the temperature, 
                                                        // and 'int' stores 16 bits.
  int binary_F = (binary_C * (9.0/5.0)) + (32 << 4);

  int resolution = 0b1000;                              // this dictates how precise the
                                                        // displayed temperature will be. This is
                                                        // going to run into some kind of problem
                                                        // at negative temperatures, but I'm not
                                                        // taking the time to figure it out.
  byte val = 0;
  for (byte index = 0; index <= 7; index++) {
    if ((binary_F & (resolution << index)) == (resolution << index)) {
      val = val + (1 << index);
    }
  }
  
  TinyMegaI2C.start(96,0);                              // TPIC2810 Address: 11000000 (192) (0xC0)
                                                        // TinyMegaI2C.start(7BitAddress,R/W)
  TinyMegaI2C.write(0x44);                              // Subaddress for immediate output: 0x44
  TinyMegaI2C.write(val); 
  TinyMegaI2C.stop();
  
}
